#include <LedControl.h>

int DIN = 12;
int CS =  11;
int CLK = 10;

byte right[8] = {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}; // right is 0
byte left[8] = {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}; // left is 1

// bar pattern
byte bit0 = 0x00;
byte bit1 = 0x80;
byte bit2 = 0xC0;
byte bit3 = 0xE0;
byte bit4 = 0xF0;
byte bit5 = 0xF8;
byte bit6 = 0xFC;
byte bit7 = 0xFE;
byte bit8 = 0xFF; 

byte bits[8] = {0x80,0xC0,0xE0,0xF0,0xF8,0xFC,0xFE,0xFF};

LedControl lc=LedControl(DIN,CLK,CS,2);

// Mic input definitions
const int sampleWindow = 150; // Sample window width in mS (50 mS = 20Hz)
unsigned int sample;

void setup(){
 // lc.shutdown(0,false);       //The MAX72XX is in power-saving mode on startup
 for(int index=0;index<lc.getDeviceCount();index++) {
        lc.shutdown(index,false); 
    } 
    
 lc.setIntensity(0,0);      // Set the brightness to maximum value
 lc.setIntensity(1,0);      // Set the brightness to maximum value
 lc.clearDisplay(0);         // and clear the display
 lc.clearDisplay(1);         // and clear the display

 Serial.begin(9600);
}

void loop(){
   unsigned long startMillis= millis();  // Start of sample window
   unsigned int peakToPeak = 0;   // peak-to-peak level

   unsigned int signalMax = 0;
   unsigned int signalMin = 1024;

   int level = 0;
   byte audio;
   
   // collect data for 150 mS
   while (millis() - startMillis < sampleWindow)
   {
      sample = analogRead(0);
      if (sample < 1024)  // toss out spurious readings
      {
         if (sample > signalMax)
         {
            signalMax = sample;  // save just the max levels
         }
         else if (sample < signalMin)
         {
            signalMin = sample;  // save just the min levels
         }
      }
   }
   peakToPeak = signalMax - signalMin;  // max - min = peak-peak amplitude
   double volts = (peakToPeak * 5.0) / 1024;  // convert to volts

   level = volts * 100;
   Serial.println(level);
   
// bar pattern
// bit0 = 0x00, bit1 = 0x80, bit2 = 0xC0, bit3 = 0xE0, bit4 = 0xF0
// bit5 = 0xF8, bit6 = 0xFC, bit7 = 0xFE, bit8 = 0xFF
 
   if (level > 100 && level < 137) {
      audio = bit1;
      // Serial.println("*");
   }
   else if (level > 137 && level < 174) {
      audio = bit2;
      // Serial.println("**");
   }
   else if (level > 174 && level < 211) {
      audio = bit3;
      // Serial.println("***");
   }
   else if (level > 211 && level < 248) {
      audio = bit4;
      // Serial.println("****");
   }
   else if (level > 248 && level < 285) {
      audio = bit5; 
      // Serial.println("*****");
   }
   else if (level > 285 && level < 322) {
      audio = bit6;  
      // Serial.println("******");
   }
   else if (level > 322 && level < 359) {
      audio = bit7; 
      // Serial.println("*******");
   }
   else if (level > 359) {
      audio = bit8;
      // Serial.println("********");
   }
   else if (level < 100) {
      audio = bit0; 
      // Serial.println(" ");
   }
   
   int l_out;
   
   l_out = left[0];
   for(int i=0;i<7;i++) {
      left[i] = left[i+1];
   }
   left[7] = right[0];
   for(int i=0;i<7;i++) {
      right[i] = right[i+1];
   }
   right[7] = audio;

   printByte(right, 0);
   printByte(left, 1);
}

void printByte(byte character [], int dev)
{
    int i = 0;
    for(i=0;i<8;i++)
    {
       lc.setRow(dev,i,character[i]);
    }
}
